@@ -23,11 +23,11 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "../include/bitfile.h"
+#include "bitfile.h"
 
 #include <assert.h>
-#include "../include/gamma.h"
-#include "../include/zeta.h"
+#include "gamma.h"
+#include "zeta.h"
 
 /**
  * Allocate a few lookup tables to speed the computations
